<?php

namespace EventPortal\Tests\Unit\Breadcrumb;

use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Tests\TestCase;
use Illuminate\Support\Facades\Route;

class BreadcrumbTest extends TestCase
{
    /** @test */
    public function generate_breadcrumbs()
    {
        Route::get('test')->name('test.index');
        Route::get('test-2/{id}')->name('test2.index');

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('test.index'))
            ->add('Event 1', route('test2.index', 1))
            ->get();

        $this->assertEquals([
            [
                'label' => 'Events',
                'href' => 'http://localhost/test',
            ],
            [
                'label' => 'Event 1',
                'href' => 'http://localhost/test-2/1',
            ],
        ], $breadcrumbs);
    }

    /** @test */
    public function generate_with_blank_route()
    {
        Route::get('test')->name('test.index');

        $breadcrumbs = Breadcrumb::make()
            ->add('Past page', route('test.index'))
            ->add('Current page')
            ->get();

        $this->assertEquals([
            [
                'label' => 'Past page',
                'href' => 'http://localhost/test',
            ],
            [
                'label' => 'Current page',
                'href' => '',
            ],
        ], $breadcrumbs);
    }
}
